# sphinx-book-theme

[![codecov](https://codecov.io/gh/ExecutableBookProject/sphinx-book-theme/branch/master/graph/badge.svg)](https://codecov.io/gh/ExecutableBookProject/sphinx-book-theme) | [![Documentation Status](https://readthedocs.org/projects/sphinx-book-theme/badge/?version=latest)](https://sphinx-book-theme.readthedocs.io/en/latest/?badge=latest)


A lightweight book theme built off of the pydata sphinx theme
